@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::ArgPassing::Mixed;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -9,57 +9,57 @@ our $results = [
     [
       {
         dataset     => "pos=3 named=5",
-        errors      => 1e-11,
+        errors      => 9.5e-12,
         participant => "list_then_hash",
-        rate        => 652120,
+        rate        => 634320,
         samples     => 20,
-        time        => 1.5335,
+        time        => 1.5765,
         vs_slowest  => 1,
       },
       {
         dataset     => "pos=3 named=1",
-        errors      => 1e-11,
+        errors      => 0,
         participant => "list_then_hash",
-        rate        => 1326000,
+        rate        => 1319820,
         samples     => 20,
-        time        => 0.754,
-        vs_slowest  => 2.034,
+        time        => 0.757677,
+        vs_slowest  => 2.0807,
       },
       {
         dataset     => "pos=3 named=5",
-        errors      => 1.8e-10,
+        errors      => 0,
         participant => "opt_hashref_at_the_front",
-        rate        => 1400000,
-        samples     => 27,
-        time        => 0.714,
-        vs_slowest  => 2.15,
+        rate        => 1391360,
+        samples     => 20,
+        time        => 0.718721,
+        vs_slowest  => 2.19348,
       },
       {
         dataset     => "pos=3 named=5",
-        errors      => 4.8e-10,
+        errors      => 0,
         participant => "hashref_at_the_front",
-        rate        => 1520000,
-        samples     => 27,
-        time        => 0.656,
-        vs_slowest  => 2.34,
+        rate        => 1515030,
+        samples     => 20,
+        time        => 0.660054,
+        vs_slowest  => 2.38844,
       },
       {
         dataset     => "pos=3 named=1",
-        errors      => 2.1e-10,
+        errors      => 9.7e-12,
         participant => "opt_hashref_at_the_front",
-        rate        => 2280000,
+        rate        => 2245000,
         samples     => 20,
-        time        => 0.438,
-        vs_slowest  => 3.5,
+        time        => 0.4454,
+        vs_slowest  => 3.54,
       },
       {
         dataset     => "pos=3 named=1",
-        errors      => 1.1e-11,
+        errors      => 5.6e-10,
         participant => "hashref_at_the_front",
-        rate        => 2552000,
-        samples     => 20,
-        time        => 0.3918,
-        vs_slowest  => 3.914,
+        rate        => 2600000,
+        samples     => 25,
+        time        => 0.39,
+        vs_slowest  => 4.1,
       },
     ],
     {
@@ -182,7 +182,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2823.296,
+                                              speed                        => "2851.460",
                                               stepping                     => 4,
                                             },
                                             {
@@ -297,7 +297,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2887.281,
+                                              speed                        => 2601.812,
                                               stepping                     => 4,
                                             },
                                             {
@@ -412,7 +412,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2877.273,
+                                              speed                        => 2885.476,
                                               stepping                     => 4,
                                             },
                                             {
@@ -527,11 +527,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => "2774.460",
+                                              speed                        => 2600.718,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.144098043441772,
+      "func.elapsed_time"              => 0.157994985580444,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "Bencher::Scenario::ArgPassing::Mixed" => undef,
@@ -571,9 +571,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1485170687,
       "func.scenario_module_sha1sum"   => "450b615deaabdff2757ac2eb42d877a288c9cdf1",
       "func.scenario_module_sha256sum" => "87a8abedb6bf719923bea62933de5314d2ba61e3adb8db1f02b4a36996498007",
-      "func.time_end"                  => 1485170773.02991,
+      "func.time_end"                  => 1485183459.07958,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1485170772.88581,
+      "func.time_start"                => 1485183458.92158,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
       "table.fields"                   => [
